@@ -1,6 +1,6 @@
 package HTML::HTPL::Config;
 
-require "/usr/local/apache/cgi-bin/htpl-config.pl";
+require "/home/httpd/cgi-bin/htpl-config.pl";
 
 require "./htpl-site.pl" if (-f "htpl-site.pl");
  
